@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003, 2004 GraphicsMagick Group
+  Copyright (C) 2003 - 2013 GraphicsMagick Group
  
   This program is covered by multiple licenses, which are described in
   Copyright.txt. You should have received a copy of Copyright.txt with this
@@ -9,8 +9,9 @@
 
   Obtained via:
 
-  nm -p magick/.libs/libGraphicsMagick.a | grep ' T ' | egrep -v '(Gm)|(lt_)' | sort | \
-     awk '{ printf("#define %s Gm%s\n", $3, $3); }'
+  nm -p magick/.libs/libGraphicsMagick.a | grep ' T ' | egrep -vi '(Gm)|(lt_)' | \
+     egrep -v '(MagickError)|(MagickFatalError)|(MagickWarning)|(ThrowException)' | \
+     awk '{ printf("#define %s Gm%s\n", $3, $3); }' | sort
 
 */
 
@@ -18,80 +19,116 @@
 #define _MAGICK_SYMBOLS_H
 
 #if defined(PREFIX_MAGICK_SYMBOLS)
+
+#define AccessCacheViewPixels GmAccessCacheViewPixels
+#define AccessDefaultCacheView GmAccessDefaultCacheView
 #define AccessDefinition GmAccessDefinition
+#define AccessImmutableIndexes GmAccessImmutableIndexes
+#define AccessMutableIndexes GmAccessMutableIndexes
+#define AccessMutablePixels GmAccessMutablePixels
+#define AccessThreadViewData GmAccessThreadViewData
+#define AccessThreadViewDataById GmAccessThreadViewDataById
 #define AcquireCacheView GmAcquireCacheView
+#define AcquireCacheViewIndexes GmAcquireCacheViewIndexes
+#define AcquireCacheViewPixels GmAcquireCacheViewPixels
 #define AcquireImagePixels GmAcquireImagePixels
+#define AcquireMagickRandomKernel GmAcquireMagickRandomKernel
 #define AcquireMagickResource GmAcquireMagickResource
 #define AcquireMemory GmAcquireMemory
+#define AcquireOneCacheViewPixel GmAcquireOneCacheViewPixel
 #define AcquireOnePixel GmAcquireOnePixel
+#define AcquireOnePixelByReference GmAcquireOnePixelByReference
 #define AcquireSemaphoreInfo GmAcquireSemaphoreInfo
 #define AcquireString GmAcquireString
 #define AcquireTemporaryFileDescriptor GmAcquireTemporaryFileDescriptor
 #define AcquireTemporaryFileName GmAcquireTemporaryFileName
 #define AcquireTemporaryFileStream GmAcquireTemporaryFileStream
 #define AdaptiveThresholdImage GmAdaptiveThresholdImage
+#define AddDefinition GmAddDefinition
 #define AddDefinitions GmAddDefinitions
 #define AddNoiseImage GmAddNoiseImage
+#define AddNoiseImageChannel GmAddNoiseImageChannel
 #define AffineTransformImage GmAffineTransformImage
 #define AllocateImage GmAllocateImage
 #define AllocateImageColormap GmAllocateImageColormap
-#define AllocateManagedString GmAllocateManagedString
+#define AllocateImageProfileIterator GmAllocateImageProfileIterator
 #define AllocateNextImage GmAllocateNextImage
 #define AllocateSemaphoreInfo GmAllocateSemaphoreInfo
 #define AllocateString GmAllocateString
+#define AllocateThreadViewDataArray GmAllocateThreadViewDataArray
+#define AllocateThreadViewDataSet GmAllocateThreadViewDataSet
+#define AllocateThreadViewSet GmAllocateThreadViewSet
 #define AnalyzeImage GmAnalyzeImage
 #define AnimateImageCommand GmAnimateImageCommand
 #define AnimateImages GmAnimateImages
 #define AnnotateImage GmAnnotateImage
 #define AppendImageFormat GmAppendImageFormat
+#define AppendImageProfile GmAppendImageProfile
 #define AppendImageToList GmAppendImageToList
 #define AppendImages GmAppendImages
 #define Ascii85Encode GmAscii85Encode
 #define Ascii85Flush GmAscii85Flush
 #define Ascii85Initialize GmAscii85Initialize
 #define Ascii85WriteByteHook GmAscii85WriteByteHook
+#define AssignThreadViewData GmAssignThreadViewData
 #define AttachBlob GmAttachBlob
+#define AutoOrientImage GmAutoOrientImage
 #define AverageImages GmAverageImages
 #define BackgroundColor GmBackgroundColor
 #define Base64Decode GmBase64Decode
 #define Base64Encode GmBase64Encode
+#define BenchmarkImageCommand GmBenchmarkImageCommand
+#define BlackThresholdImage GmBlackThresholdImage
 #define BlobIsSeekable GmBlobIsSeekable
+#define BlobModeToString GmBlobModeToString
+#define BlobReserveSize GmBlobReserveSize
 #define BlobToFile GmBlobToFile
 #define BlobToImage GmBlobToImage
 #define BlobWriteByteHook GmBlobWriteByteHook
 #define BlurImage GmBlurImage
+#define BlurImageChannel GmBlurImageChannel
 #define BorderColor GmBorderColor
 #define BorderImage GmBorderImage
 #define CatchException GmCatchException
 #define CatchImageException GmCatchImageException
+#define CdlImage GmCdlImage
 #define ChannelImage GmChannelImage
 #define ChannelThresholdImage GmChannelThresholdImage
+#define ChannelTypeToString GmChannelTypeToString
 #define CharcoalImage GmCharcoalImage
 #define ChopImage GmChopImage
+#define ClassTypeToString GmClassTypeToString
 #define ClipImage GmClipImage
 #define ClipPathImage GmClipPathImage
 #define CloneBlobInfo GmCloneBlobInfo
 #define CloneDrawInfo GmCloneDrawInfo
 #define CloneImage GmCloneImage
+#define CloneImageAttributes GmCloneImageAttributes
 #define CloneImageInfo GmCloneImageInfo
 #define CloneImageList GmCloneImageList
 #define CloneMemory GmCloneMemory
 #define CloneMontageInfo GmCloneMontageInfo
-#define ClonePixelCacheMethods GmClonePixelCacheMethods
 #define CloneQuantizeInfo GmCloneQuantizeInfo
 #define CloneString GmCloneString
 #define CloseBlob GmCloseBlob
 #define CloseCacheView GmCloseCacheView
 #define CoalesceImages GmCoalesceImages
 #define ColorFloodfillImage GmColorFloodfillImage
+#define ColorMatrixImage GmColorMatrixImage
 #define ColorizeImage GmColorizeImage
 #define ColorspaceTypeToString GmColorspaceTypeToString
+#define CompareImageCommand GmCompareImageCommand
 #define CompositeImage GmCompositeImage
 #define CompositeImageCommand GmCompositeImageCommand
+#define CompositeImageRegion GmCompositeImageRegion
+#define CompositeOperatorToString GmCompositeOperatorToString
 #define CompressImageColormap GmCompressImageColormap
+#define CompressionTypeToString GmCompressionTypeToString
 #define ConcatenateString GmConcatenateString
+#define ConfirmAccessModeToString GmConfirmAccessModeToString
 #define ConjureImageCommand GmConjureImageCommand
 #define ConstituteImage GmConstituteImage
+#define ConstituteTextureImage GmConstituteTextureImage
 #define ContinueTimer GmContinueTimer
 #define Contrast GmContrast
 #define ContrastImage GmContrastImage
@@ -100,6 +137,8 @@
 #define CopyException GmCopyException
 #define CropImage GmCropImage
 #define CycleColormapImage GmCycleColormapImage
+#define DCM_SetRescaling GmDCM_SetRescaling
+#define DeallocateImageProfileIterator GmDeallocateImageProfileIterator
 #define DeconstructImages GmDeconstructImages
 #define DefaultTileFrame GmDefaultTileFrame
 #define DefaultTileGeometry GmDefaultTileGeometry
@@ -107,11 +146,11 @@
 #define DefineClientName GmDefineClientName
 #define DefineClientPathAndName GmDefineClientPathAndName
 #define DeleteImageFromList GmDeleteImageFromList
-#define DeleteImageList GmDeleteImageList
 #define DeleteImageProfile GmDeleteImageProfile
 #define DeleteMagickRegistry GmDeleteMagickRegistry
 #define DescribeImage GmDescribeImage
 #define DespeckleImage GmDespeckleImage
+#define DestroyBlob GmDestroyBlob
 #define DestroyBlobInfo GmDestroyBlobInfo
 #define DestroyCacheInfo GmDestroyCacheInfo
 #define DestroyColorInfo GmDestroyColorInfo
@@ -124,22 +163,22 @@
 #define DestroyImageInfo GmDestroyImageInfo
 #define DestroyImageList GmDestroyImageList
 #define DestroyImagePixels GmDestroyImagePixels
-#define DestroyImages GmDestroyImages
 #define DestroyLogInfo GmDestroyLogInfo
 #define DestroyMagicInfo GmDestroyMagicInfo
 #define DestroyMagick GmDestroyMagick
-#define DestroyMagickInfo GmDestroyMagickInfo
-#define DestroyMagickModules GmDestroyMagickModules
+#define DestroyMagickRandomGenerator GmDestroyMagickRandomGenerator
 #define DestroyMagickRegistry GmDestroyMagickRegistry
 #define DestroyMagickResources GmDestroyMagickResources
-#define DestroyModuleInfo GmDestroyModuleInfo
 #define DestroyMontageInfo GmDestroyMontageInfo
 #define DestroyQuantizeInfo GmDestroyQuantizeInfo
 #define DestroySemaphore GmDestroySemaphore
 #define DestroySemaphoreInfo GmDestroySemaphoreInfo
 #define DestroyTemporaryFiles GmDestroyTemporaryFiles
+#define DestroyThreadViewDataSet GmDestroyThreadViewDataSet
+#define DestroyThreadViewSet GmDestroyThreadViewSet
 #define DestroyTypeInfo GmDestroyTypeInfo
 #define DetachBlob GmDetachBlob
+#define DifferenceImage GmDifferenceImage
 #define DispatchImage GmDispatchImage
 #define DisplayImageCommand GmDisplayImageCommand
 #define DisplayImages GmDisplayImages
@@ -215,7 +254,6 @@
 #define DrawPopDefs GmDrawPopDefs
 #define DrawPopGraphicContext GmDrawPopGraphicContext
 #define DrawPopPattern GmDrawPopPattern
-#define DrawPrimitive GmDrawPrimitive
 #define DrawPushClipPath GmDrawPushClipPath
 #define DrawPushDefs GmDrawPushDefs
 #define DrawPushGraphicContext GmDrawPushGraphicContext
@@ -263,16 +301,19 @@
 #define EOFBlob GmEOFBlob
 #define EdgeImage GmEdgeImage
 #define EmbossImage GmEmbossImage
+#define EndianTypeToString GmEndianTypeToString
 #define EnhanceImage GmEnhanceImage
 #define EqualizeImage GmEqualizeImage
 #define EscapeString GmEscapeString
 #define ExecuteModuleProcess GmExecuteModuleProcess
-#define ExecuteStaticModuleProcess GmExecuteStaticModuleProcess
 #define ExpandAffine GmExpandAffine
 #define ExpandFilename GmExpandFilename
 #define ExpandFilenames GmExpandFilenames
 #define ExportImageChannel GmExportImageChannel
 #define ExportImagePixelArea GmExportImagePixelArea
+#define ExportPixelAreaOptionsInit GmExportPixelAreaOptionsInit
+#define ExportViewPixelArea GmExportViewPixelArea
+#define ExtentImage GmExtentImage
 #define FileToBlob GmFileToBlob
 #define FinalizeSignature GmFinalizeSignature
 #define FlattenImages GmFlattenImages
@@ -286,21 +327,23 @@
 #define FuzzyColorMatch GmFuzzyColorMatch
 #define GammaImage GmGammaImage
 #define GaussianBlurImage GmGaussianBlurImage
+#define GaussianBlurImageChannel GmGaussianBlurImageChannel
+#define GenerateDifferentialNoise GmGenerateDifferentialNoise
 #define GenerateNoise GmGenerateNoise
-#define GetBlobClosable GmGetBlobClosable
 #define GetBlobFileHandle GmGetBlobFileHandle
 #define GetBlobInfo GmGetBlobInfo
+#define GetBlobIsOpen GmGetBlobIsOpen
 #define GetBlobSize GmGetBlobSize
 #define GetBlobStatus GmGetBlobStatus
 #define GetBlobStreamData GmGetBlobStreamData
-#define GetBlobStreamHandler GmGetBlobStreamHandler
 #define GetBlobTemporary GmGetBlobTemporary
-#define GetCacheClass GmGetCacheClass
-#define GetCacheColorspace GmGetCacheColorspace
 #define GetCacheInfo GmGetCacheInfo
 #define GetCacheView GmGetCacheView
+#define GetCacheViewArea GmGetCacheViewArea
+#define GetCacheViewImage GmGetCacheViewImage
 #define GetCacheViewIndexes GmGetCacheViewIndexes
 #define GetCacheViewPixels GmGetCacheViewPixels
+#define GetCacheViewRegion GmGetCacheViewRegion
 #define GetClientFilename GmGetClientFilename
 #define GetClientName GmGetClientName
 #define GetClientPath GmGetClientPath
@@ -322,9 +365,13 @@
 #define GetImageAttribute GmGetImageAttribute
 #define GetImageBoundingBox GmGetImageBoundingBox
 #define GetImageChannelDepth GmGetImageChannelDepth
+#define GetImageChannelDifference GmGetImageChannelDifference
+#define GetImageChannelDistortion GmGetImageChannelDistortion
+#define GetImageCharacteristics GmGetImageCharacteristics
 #define GetImageClipMask GmGetImageClipMask
 #define GetImageClippingPathAttribute GmGetImageClippingPathAttribute
 #define GetImageDepth GmGetImageDepth
+#define GetImageDistortion GmGetImageDistortion
 #define GetImageException GmGetImageException
 #define GetImageFromList GmGetImageFromList
 #define GetImageFromMagickRegistry GmGetImageFromMagickRegistry
@@ -332,14 +379,13 @@
 #define GetImageIndexInList GmGetImageIndexInList
 #define GetImageInfo GmGetImageInfo
 #define GetImageInfoAttribute GmGetImageInfoAttribute
-#define GetImageList GmGetImageList
-#define GetImageListIndex GmGetImageListIndex
 #define GetImageListLength GmGetImageListLength
-#define GetImageListSize GmGetImageListSize
 #define GetImageMagick GmGetImageMagick
 #define GetImagePixels GmGetImagePixels
+#define GetImagePixelsEx GmGetImagePixelsEx
 #define GetImageProfile GmGetImageProfile
 #define GetImageQuantizeError GmGetImageQuantizeError
+#define GetImageStatistics GmGetImageStatistics
 #define GetImageType GmGetImageType
 #define GetImageVirtualPixelMethod GmGetImageVirtualPixelMethod
 #define GetIndexes GmGetIndexes
@@ -347,24 +393,20 @@
 #define GetLocaleExceptionMessage GmGetLocaleExceptionMessage
 #define GetLocaleMessage GmGetLocaleMessage
 #define GetLocaleMessageFromID GmGetLocaleMessageFromID
-#define GetLocaleMessageFromSeverityAndTag GmGetLocaleMessageFromSeverityAndTag
-#define GetLocaleMessageFromTag GmGetLocaleMessageFromTag
-#define GetMagicInfo GmGetMagicInfo
 #define GetMagickCopyright GmGetMagickCopyright
 #define GetMagickDimension GmGetMagickDimension
+#define GetMagickFileFormat GmGetMagickFileFormat
 #define GetMagickGeometry GmGetMagickGeometry
 #define GetMagickInfo GmGetMagickInfo
 #define GetMagickInfoArray GmGetMagickInfoArray
 #define GetMagickRegistry GmGetMagickRegistry
 #define GetMagickResource GmGetMagickResource
+#define GetMagickResourceLimit GmGetMagickResourceLimit
 #define GetMagickVersion GmGetMagickVersion
 #define GetMagickWebSite GmGetMagickWebSite
-#define GetModuleInfo GmGetModuleInfo
 #define GetMontageInfo GmGetMontageInfo
-#define GetNextImage GmGetNextImage
 #define GetNextImageInList GmGetNextImageInList
 #define GetNumberColors GmGetNumberColors
-#define GetNumberScenes GmGetNumberScenes
 #define GetOnePixel GmGetOnePixel
 #define GetOptimalKernelWidth GmGetOptimalKernelWidth
 #define GetOptimalKernelWidth1D GmGetOptimalKernelWidth1D
@@ -372,12 +414,16 @@
 #define GetPageGeometry GmGetPageGeometry
 #define GetPathComponent GmGetPathComponent
 #define GetPixelCacheArea GmGetPixelCacheArea
+#define GetPixelCacheInCore GmGetPixelCacheInCore
+#define GetPixelCachePresent GmGetPixelCachePresent
 #define GetPixels GmGetPixels
-#define GetPreviousImage GmGetPreviousImage
+#define GetPostscriptDelegateInfo GmGetPostscriptDelegateInfo
 #define GetPreviousImageInList GmGetPreviousImageInList
 #define GetQuantizeInfo GmGetQuantizeInfo
 #define GetSignatureInfo GmGetSignatureInfo
+#define GetThreadViewDataSetAllocatedViews GmGetThreadViewDataSetAllocatedViews
 #define GetTimerInfo GmGetTimerInfo
+#define GetTimerResolution GmGetTimerResolution
 #define GetToken GmGetToken
 #define GetTypeInfo GmGetTypeInfo
 #define GetTypeInfoByFamily GmGetTypeInfoByFamily
@@ -389,6 +435,8 @@
 #define GrayscalePseudoClassImage GmGrayscalePseudoClassImage
 #define HSLTransform GmHSLTransform
 #define HWBTransform GmHWBTransform
+#define HaldClutImage GmHaldClutImage
+#define HighlightStyleToString GmHighlightStyleToString
 #define HuffmanDecodeImage GmHuffmanDecodeImage
 #define HuffmanEncode2Image GmHuffmanEncode2Image
 #define HuffmanEncodeImage GmHuffmanEncodeImage
@@ -398,19 +446,39 @@
 #define ImageListToArray GmImageListToArray
 #define ImageToBlob GmImageToBlob
 #define ImageToFile GmImageToFile
+#define ImageToHuffman2DBlob GmImageToHuffman2DBlob
+#define ImageToJPEGBlob GmImageToJPEGBlob
+#define ImageTypeToString GmImageTypeToString
 #define ImplodeImage GmImplodeImage
 #define ImportImageChannel GmImportImageChannel
+#define ImportImageChannelsMasked GmImportImageChannelsMasked
 #define ImportImageCommand GmImportImageCommand
 #define ImportImagePixelArea GmImportImagePixelArea
+#define ImportPixelAreaOptionsInit GmImportPixelAreaOptionsInit
+#define ImportViewPixelArea GmImportViewPixelArea
+#define InitializeColorInfo GmInitializeColorInfo
+#define InitializeConstitute GmInitializeConstitute
+#define InitializeDelegateInfo GmInitializeDelegateInfo
+#define InitializeDifferenceImageOptions GmInitializeDifferenceImageOptions
+#define InitializeDifferenceStatistics GmInitializeDifferenceStatistics
 #define InitializeLogInfo GmInitializeLogInfo
+#define InitializeMagicInfo GmInitializeMagicInfo
 #define InitializeMagick GmInitializeMagick
 #define InitializeMagickClientPathAndName GmInitializeMagickClientPathAndName
-#define InitializeMagickModules GmInitializeMagickModules
+#define InitializeMagickRandomGenerator GmInitializeMagickRandomGenerator
+#define InitializeMagickRandomKernel GmInitializeMagickRandomKernel
+#define InitializeMagickRegistry GmInitializeMagickRegistry
 #define InitializeMagickResources GmInitializeMagickResources
 #define InitializeMagickSignalHandlers GmInitializeMagickSignalHandlers
+#define InitializePixelIteratorOptions GmInitializePixelIteratorOptions
 #define InitializeSemaphore GmInitializeSemaphore
+#define InitializeTemporaryFiles GmInitializeTemporaryFiles
+#define InitializeTypeInfo GmInitializeTypeInfo
 #define InsertImageInList GmInsertImageInList
+#define InsertRowHDU GmInsertRowHDU
+#define InterlaceTypeToString GmInterlaceTypeToString
 #define InterpolateColor GmInterpolateColor
+#define InterpolateViewColor GmInterpolateViewColor
 #define InvokeDelegate GmInvokeDelegate
 #define InvokePostscriptDelegate GmInvokePostscriptDelegate
 #define IsAccessible GmIsAccessible
@@ -427,7 +495,6 @@
 #define IsPaletteImage GmIsPaletteImage
 #define IsSubimage GmIsSubimage
 #define IsTaintImage GmIsTaintImage
-#define IsTrue GmIsTrue
 #define IsWriteable GmIsWriteable
 #define LZWEncode2Image GmLZWEncode2Image
 #define LZWEncodeImage GmLZWEncodeImage
@@ -443,11 +510,8 @@
 #define ListMagicInfo GmListMagicInfo
 #define ListMagickInfo GmListMagickInfo
 #define ListMagickResourceInfo GmListMagickResourceInfo
-#define ListModuleInfo GmListModuleInfo
 #define ListModuleMap GmListModuleMap
 #define ListTypeInfo GmListTypeInfo
-#define LoadImageText GmLoadImageText
-#define LoadImagesText GmLoadImagesText
 #define LocaleCompare GmLocaleCompare
 #define LocaleLower GmLocaleLower
 #define LocaleNCompare GmLocaleNCompare
@@ -455,9 +519,36 @@
 #define LockSemaphoreInfo GmLockSemaphoreInfo
 #define LogMagickEvent GmLogMagickEvent
 #define LogMagickEventList GmLogMagickEventList
+#define MatteColor GmMatteColor
 #define MSBOrderLong GmMSBOrderLong
 #define MSBOrderShort GmMSBOrderShort
+#define MagickAllocFunctions GmMagickAllocFunctions
+#define MagickArraySize GmMagickArraySize
+#define MagickBitStreamInitializeRead GmMagickBitStreamInitializeRead
+#define MagickBitStreamInitializeWrite GmMagickBitStreamInitializeWrite
+#define MagickBitStreamMSBRead GmMagickBitStreamMSBRead
+#define MagickBitStreamMSBWrite GmMagickBitStreamMSBWrite
+#define MagickCloneMemory GmMagickCloneMemory
 #define MagickCommand GmMagickCommand
+#define MagickCompositeImageUnderColor GmMagickCompositeImageUnderColor
+#define MagickConfirmAccess GmMagickConfirmAccess
+#define MagickConstrainColormapIndex GmMagickConstrainColormapIndex
+#define MagickCreateDirectoryPath GmMagickCreateDirectoryPath
+#define MagickDestroyCommandInfo GmMagickDestroyCommandInfo
+#define MagickFindRawImageMinMax GmMagickFindRawImageMinMax
+#define MagickFree GmMagickFree
+#define MagickFreeAligned GmMagickFreeAligned
+#define MagickGetBitRevTable GmMagickGetBitRevTable
+#define MagickGetFileSystemBlockSize GmMagickGetFileSystemBlockSize
+#define MagickGetMMUPageSize GmMagickGetMMUPageSize
+#define MagickGetQuantumSamplesPerPixel GmMagickGetQuantumSamplesPerPixel
+#define MagickInitializeCommandInfo GmMagickInitializeCommandInfo
+#define MagickIsTrue GmMagickIsTrue
+#define MagickMalloc GmMagickMalloc
+#define MagickMallocAligned GmMagickMallocAligned
+#define MagickMallocAlignedArray GmMagickMallocAlignedArray
+#define MagickMallocArray GmMagickMallocArray
+#define MagickMallocCleared GmMagickMallocCleared
 #define MagickMapAccessEntry GmMagickMapAccessEntry
 #define MagickMapAddEntry GmMagickMapAddEntry
 #define MagickMapAllocateIterator GmMagickMapAllocateIterator
@@ -477,15 +568,122 @@
 #define MagickMapIterateToFront GmMagickMapIterateToFront
 #define MagickMapRemoveEntry GmMagickMapRemoveEntry
 #define MagickMonitor GmMagickMonitor
+#define MagickMonitorFormatted GmMagickMonitorFormatted
+#define MagickRandNewSeed GmMagickRandNewSeed
+#define MagickRandReentrant GmMagickRandReentrant
+#define MagickRandomInteger GmMagickRandomInteger
+#define MagickRandomReal GmMagickRandomReal
+#define MagickRealloc GmMagickRealloc
+#define MagickReverseBits GmMagickReverseBits
+#define MagickSceneFileName GmMagickSceneFileName
+#define MagickSetConfirmAccessHandler GmMagickSetConfirmAccessHandler
+#define MagickSetFileSystemBlockSize GmMagickSetFileSystemBlockSize
+#define MagickSizeStrToInt64 GmMagickSizeStrToInt64
+#define MagickSpawnVP GmMagickSpawnVP
+#define MagickStrlCat GmMagickStrlCat
+#define MagickStrlCpy GmMagickStrlCpy
+#define MagickStrlCpyTrunc GmMagickStrlCpyTrunc
+#define MagickSwabArrayOfDouble GmMagickSwabArrayOfDouble
+#define MagickSwabArrayOfFloat GmMagickSwabArrayOfFloat
+#define MagickSwabArrayOfUInt16 GmMagickSwabArrayOfUInt16
+#define MagickSwabArrayOfUInt32 GmMagickSwabArrayOfUInt32
+#define MagickSwabDouble GmMagickSwabDouble
+#define MagickSwabFloat GmMagickSwabFloat
+#define MagickSwabUInt16 GmMagickSwabUInt16
+#define MagickSwabUInt32 GmMagickSwabUInt32
 #define MagickToMime GmMagickToMime
+#define MagickTsdGetSpecific GmMagickTsdGetSpecific
+#define MagickTsdKeyCreate GmMagickTsdKeyCreate
+#define MagickTsdKeyCreate2 GmMagickTsdKeyCreate2
+#define MagickTsdKeyDelete GmMagickTsdKeyDelete
+#define MagickTsdSetSpecific GmMagickTsdSetSpecific
+#define MagickWordStreamInitializeRead GmMagickWordStreamInitializeRead
+#define MagickWordStreamInitializeWrite GmMagickWordStreamInitializeWrite
+#define MagickWordStreamLSBRead GmMagickWordStreamLSBRead
+#define MagickWordStreamLSBWrite GmMagickWordStreamLSBWrite
+#define MagickWordStreamLSBWriteFlush GmMagickWordStreamLSBWriteFlush
+#define MagickXAnimateBackgroundImage GmMagickXAnimateBackgroundImage
+#define MagickXAnimateImages GmMagickXAnimateImages
+#define MagickXAnnotateImage GmMagickXAnnotateImage
+#define MagickXBestFont GmMagickXBestFont
+#define MagickXBestIconSize GmMagickXBestIconSize
+#define MagickXBestPixel GmMagickXBestPixel
+#define MagickXBestVisualInfo GmMagickXBestVisualInfo
+#define MagickXCheckRefreshWindows GmMagickXCheckRefreshWindows
+#define MagickXClientMessage GmMagickXClientMessage
+#define MagickXColorBrowserWidget GmMagickXColorBrowserWidget
+#define MagickXCommandWidget GmMagickXCommandWidget
+#define MagickXConfigureImageColormap GmMagickXConfigureImageColormap
+#define MagickXConfirmWidget GmMagickXConfirmWidget
+#define MagickXConstrainWindowPosition GmMagickXConstrainWindowPosition
+#define MagickXDelay GmMagickXDelay
+#define MagickXDestroyResourceInfo GmMagickXDestroyResourceInfo
+#define MagickXDestroyWindowColors GmMagickXDestroyWindowColors
+#define MagickXDestroyX11Resources GmMagickXDestroyX11Resources
+#define MagickXDestroyXWindowInfo GmMagickXDestroyXWindowInfo
+#define MagickXDestroyXWindows GmMagickXDestroyXWindows
+#define MagickXDialogWidget GmMagickXDialogWidget
+#define MagickXDisplayBackgroundImage GmMagickXDisplayBackgroundImage
+#define MagickXDisplayImage GmMagickXDisplayImage
+#define MagickXDisplayImageInfo GmMagickXDisplayImageInfo
+#define MagickXDrawImage GmMagickXDrawImage
+#define MagickXError GmMagickXError
+#define MagickXFileBrowserWidget GmMagickXFileBrowserWidget
+#define MagickXFontBrowserWidget GmMagickXFontBrowserWidget
+#define MagickXFreeResources GmMagickXFreeResources
+#define MagickXFreeStandardColormap GmMagickXFreeStandardColormap
+#define MagickXGetAnnotateInfo GmMagickXGetAnnotateInfo
+#define MagickXGetImportInfo GmMagickXGetImportInfo
+#define MagickXGetMapInfo GmMagickXGetMapInfo
+#define MagickXGetPixelPacket GmMagickXGetPixelPacket
+#define MagickXGetResourceClass GmMagickXGetResourceClass
+#define MagickXGetResourceDatabase GmMagickXGetResourceDatabase
+#define MagickXGetResourceInfo GmMagickXGetResourceInfo
+#define MagickXGetResourceInstance GmMagickXGetResourceInstance
+#define MagickXGetScreenDensity GmMagickXGetScreenDensity
+#define MagickXGetWindowColor GmMagickXGetWindowColor
+#define MagickXGetWindowInfo GmMagickXGetWindowInfo
+#define MagickXHighlightEllipse GmMagickXHighlightEllipse
+#define MagickXHighlightLine GmMagickXHighlightLine
+#define MagickXHighlightRectangle GmMagickXHighlightRectangle
+#define MagickXImportImage GmMagickXImportImage
+#define MagickXInfoWidget GmMagickXInfoWidget
+#define MagickXInitializeWindows GmMagickXInitializeWindows
+#define MagickXListBrowserWidget GmMagickXListBrowserWidget
+#define MagickXMagickMonitor GmMagickXMagickMonitor
+#define MagickXMakeCursor GmMagickXMakeCursor
+#define MagickXMakeImage GmMagickXMakeImage
+#define MagickXMakeMagnifyImage GmMagickXMakeMagnifyImage
+#define MagickXMakeStandardColormap GmMagickXMakeStandardColormap
+#define MagickXMakeWindow GmMagickXMakeWindow
+#define MagickXMenuWidget GmMagickXMenuWidget
+#define MagickXMonitorWidget GmMagickXMonitorWidget
+#define MagickXNoticeWidget GmMagickXNoticeWidget
+#define MagickXPreferencesWidget GmMagickXPreferencesWidget
+#define MagickXQueryColorDatabase GmMagickXQueryColorDatabase
+#define MagickXQueryPosition GmMagickXQueryPosition
+#define MagickXRefreshWindow GmMagickXRefreshWindow
+#define MagickXRemoteCommand GmMagickXRemoteCommand
+#define MagickXRetainWindowColors GmMagickXRetainWindowColors
+#define MagickXSetCursorState GmMagickXSetCursorState
+#define MagickXSetWindows GmMagickXSetWindows
+#define MagickXSignalHandler GmMagickXSignalHandler
+#define MagickXTextViewWidget GmMagickXTextViewWidget
+#define MagickXUserPreferences GmMagickXUserPreferences
+#define MagickXWarning GmMagickXWarning
+#define MagickXWindowByID GmMagickXWindowByID
+#define MagickXWindowByName GmMagickXWindowByName
+#define MagickXWindowByProperty GmMagickXWindowByProperty
 #define MagnifyImage GmMagnifyImage
 #define MapBlob GmMapBlob
 #define MapImage GmMapImage
 #define MapImages GmMapImages
-#define MatteColor GmMatteColor
+#define MapModeToString GmMapModeToString
 #define MatteFloodfillImage GmMatteFloodfillImage
 #define MedianFilterImage GmMedianFilterImage
+#define MetricTypeToString GmMetricTypeToString
 #define MinifyImage GmMinifyImage
+#define ModifyCache GmModifyCache
 #define ModifyImage GmModifyImage
 #define Modulate GmModulate
 #define ModulateImage GmModulateImage
@@ -500,35 +698,43 @@
 #define MultilineCensus GmMultilineCensus
 #define NegateImage GmNegateImage
 #define NewImageList GmNewImageList
+#define NextImageProfile GmNextImageProfile
+#define NoiseTypeToString GmNoiseTypeToString
 #define NormalizeImage GmNormalizeImage
 #define OilPaintImage GmOilPaintImage
 #define OpaqueImage GmOpaqueImage
 #define OpenBlob GmOpenBlob
-#define OpenCache GmOpenCache
 #define OpenCacheView GmOpenCacheView
-#define OpenModule GmOpenModule
-#define OpenModules GmOpenModules
 #define OrderedDitherImage GmOrderedDitherImage
-#define PSDensityGeometry GmPSDensityGeometry
-#define PSPageGeometry GmPSPageGeometry
+#define OrientationTypeToString GmOrientationTypeToString
 #define PackbitsEncode2Image GmPackbitsEncode2Image
 #define PackbitsEncodeImage GmPackbitsEncodeImage
-#define ParseImageGeometry GmParseImageGeometry
 #define PersistCache GmPersistCache
 #define PingBlob GmPingBlob
 #define PingImage GmPingImage
 #define PixelIterateDualModify GmPixelIterateDualModify
+#define PixelIterateDualNew GmPixelIterateDualNew
 #define PixelIterateDualRead GmPixelIterateDualRead
 #define PixelIterateMonoModify GmPixelIterateMonoModify
 #define PixelIterateMonoRead GmPixelIterateMonoRead
+#define PixelIterateTripleModify GmPixelIterateTripleModify
+#define PixelIterateTripleNew GmPixelIterateTripleNew
 #define PlasmaImage GmPlasmaImage
-#define PopImageList GmPopImageList
-#define PostscriptGeometry GmPostscriptGeometry
+#define PopImagePixels GmPopImagePixels
 #define PrependImageToList GmPrependImageToList
 #define ProfileImage GmProfileImage
-#define PushImageList GmPushImageList
+#define PSDensityGeometry GmPSDensityGeometry
+#define PSPageGeometry GmPSPageGeometry
+#define PurgeTemporaryFiles GmPurgeTemporaryFiles
+#define PushImagePixels GmPushImagePixels
 #define QuantizeImage GmQuantizeImage
 #define QuantizeImages GmQuantizeImages
+#define QuantumOperatorImage GmQuantumOperatorImage
+#define QuantumOperatorImageMultivalue GmQuantumOperatorImageMultivalue
+#define QuantumOperatorRegionImage GmQuantumOperatorRegionImage
+#define QuantumOperatorToString GmQuantumOperatorToString
+#define QuantumSampleTypeToString GmQuantumSampleTypeToString
+#define QuantumTypeToString GmQuantumTypeToString
 #define QueryColorDatabase GmQueryColorDatabase
 #define QueryColorname GmQueryColorname
 #define RGBTransformImage GmRGBTransformImage
@@ -537,15 +743,28 @@
 #define ReacquireMemory GmReacquireMemory
 #define ReadBlob GmReadBlob
 #define ReadBlobByte GmReadBlobByte
+#define ReadBlobByteFromBuffer GmReadBlobByteFromBuffer
+#define ReadBlobLSBDouble GmReadBlobLSBDouble
+#define ReadBlobLSBDoubles GmReadBlobLSBDoubles
+#define ReadBlobLSBFloat GmReadBlobLSBFloat
+#define ReadBlobLSBFloats GmReadBlobLSBFloats
 #define ReadBlobLSBLong GmReadBlobLSBLong
+#define ReadBlobLSBLongs GmReadBlobLSBLongs
 #define ReadBlobLSBShort GmReadBlobLSBShort
+#define ReadBlobLSBShortFromBuffer GmReadBlobLSBShortFromBuffer
+#define ReadBlobLSBShorts GmReadBlobLSBShorts
+#define ReadBlobMSBDouble GmReadBlobMSBDouble
+#define ReadBlobMSBDoubles GmReadBlobMSBDoubles
+#define ReadBlobMSBFloat GmReadBlobMSBFloat
+#define ReadBlobMSBFloats GmReadBlobMSBFloats
 #define ReadBlobMSBLong GmReadBlobMSBLong
+#define ReadBlobMSBLongs GmReadBlobMSBLongs
 #define ReadBlobMSBShort GmReadBlobMSBShort
+#define ReadBlobMSBShorts GmReadBlobMSBShorts
 #define ReadBlobString GmReadBlobString
 #define ReadBlobZC GmReadBlobZC
 #define ReadImage GmReadImage
 #define ReadInlineImage GmReadInlineImage
-#define ReadStream GmReadStream
 #define ReduceNoiseImage GmReduceNoiseImage
 #define ReferenceBlob GmReferenceBlob
 #define ReferenceCache GmReferenceCache
@@ -554,20 +773,18 @@
 #define RegisterAVIImage GmRegisterAVIImage
 #define RegisterAVSImage GmRegisterAVSImage
 #define RegisterBMPImage GmRegisterBMPImage
+#define RegisterCALSImage GmRegisterCALSImage
 #define RegisterCAPTIONImage GmRegisterCAPTIONImage
 #define RegisterCINEONImage GmRegisterCINEONImage
-#define RegisterCLIPBOARDImage GmRegisterCLIPBOARDImage
 #define RegisterCMYKImage GmRegisterCMYKImage
 #define RegisterCUTImage GmRegisterCUTImage
 #define RegisterDCMImage GmRegisterDCMImage
+#define RegisterDCRAWImage GmRegisterDCRAWImage
 #define RegisterDIBImage GmRegisterDIBImage
-#define RegisterDPSImage GmRegisterDPSImage
 #define RegisterDPXImage GmRegisterDPXImage
-#define RegisterEMFImage GmRegisterEMFImage
 #define RegisterEPTImage GmRegisterEPTImage
 #define RegisterFAXImage GmRegisterFAXImage
 #define RegisterFITSImage GmRegisterFITSImage
-#define RegisterFPXImage GmRegisterFPXImage
 #define RegisterGIFImage GmRegisterGIFImage
 #define RegisterGRADIENTImage GmRegisterGRADIENTImage
 #define RegisterGRAYImage GmRegisterGRAYImage
@@ -575,7 +792,8 @@
 #define RegisterHRZImage GmRegisterHRZImage
 #define RegisterHTMLImage GmRegisterHTMLImage
 #define RegisterICONImage GmRegisterICONImage
-#define RegisterJBIGImage GmRegisterJBIGImage
+#define RegisterIDENTITYImage GmRegisterIDENTITYImage
+#define RegisterINFOImage GmRegisterINFOImage
 #define RegisterJNXImage GmRegisterJNXImage
 #define RegisterJP2Image GmRegisterJP2Image
 #define RegisterJPEGImage GmRegisterJPEGImage
@@ -653,21 +871,21 @@
 #define RemoveLastImageFromList GmRemoveLastImageFromList
 #define ReplaceImageColormap GmReplaceImageColormap
 #define ReplaceImageInList GmReplaceImageInList
+#define ResetImagePage GmResetImagePage
 #define ResetTimer GmResetTimer
+#define ResizeFilterToString GmResizeFilterToString
 #define ResizeImage GmResizeImage
 #define ReverseImageList GmReverseImageList
 #define RollImage GmRollImage
 #define RotateImage GmRotateImage
 #define SampleImage GmSampleImage
-#define SaveImageText GmSaveImageText
-#define SaveImagesText GmSaveImagesText
 #define ScaleImage GmScaleImage
 #define SeekBlob GmSeekBlob
 #define SegmentImage GmSegmentImage
 #define SetBlobClosable GmSetBlobClosable
 #define SetBlobTemporary GmSetBlobTemporary
-#define SetCacheThreshold GmSetCacheThreshold
 #define SetCacheView GmSetCacheView
+#define SetCacheViewPixels GmSetCacheViewPixels
 #define SetClientFilename GmSetClientFilename
 #define SetClientName GmSetClientName
 #define SetClientPath GmSetClientPath
@@ -680,11 +898,13 @@
 #define SetImageAttribute GmSetImageAttribute
 #define SetImageChannelDepth GmSetImageChannelDepth
 #define SetImageClipMask GmSetImageClipMask
+#define SetImageColor GmSetImageColor
+#define SetImageColorRegion GmSetImageColorRegion
 #define SetImageDepth GmSetImageDepth
 #define SetImageInfo GmSetImageInfo
-#define SetImageList GmSetImageList
 #define SetImageOpacity GmSetImageOpacity
 #define SetImagePixels GmSetImagePixels
+#define SetImagePixelsEx GmSetImagePixelsEx
 #define SetImageProfile GmSetImageProfile
 #define SetImageType GmSetImageType
 #define SetImageVirtualPixelMethod GmSetImageVirtualPixelMethod
@@ -694,33 +914,51 @@
 #define SetMagickRegistry GmSetMagickRegistry
 #define SetMagickResourceLimit GmSetMagickResourceLimit
 #define SetMonitorHandler GmSetMonitorHandler
-#define SetPixelCacheMethods GmSetPixelCacheMethods
 #define SetWarningHandler GmSetWarningHandler
 #define ShadeImage GmShadeImage
 #define SharpenImage GmSharpenImage
+#define SharpenImageChannel GmSharpenImageChannel
 #define ShaveImage GmShaveImage
 #define ShearImage GmShearImage
-#define ShiftImageList GmShiftImageList
 #define SignatureImage GmSignatureImage
-#define SizeBlob GmSizeBlob
 #define SolarizeImage GmSolarizeImage
 #define SortColormapByIntensity GmSortColormapByIntensity
 #define SpliceImageIntoList GmSpliceImageIntoList
-#define SpliceImageList GmSpliceImageList
 #define SplitImageList GmSplitImageList
 #define SpreadImage GmSpreadImage
 #define SteganoImage GmSteganoImage
 #define StereoImage GmStereoImage
+#define StorageTypeToString GmStorageTypeToString
+#define StretchTypeToString GmStretchTypeToString
 #define StringToArgv GmStringToArgv
+#define StringToChannelType GmStringToChannelType
 #define StringToColorspaceType GmStringToColorspaceType
+#define StringToCompositeOperator GmStringToCompositeOperator
+#define StringToCompressionType GmStringToCompressionType
 #define StringToDouble GmStringToDouble
+#define StringToEndianType GmStringToEndianType
+#define StringToFilterTypes GmStringToFilterTypes
+#define StringToGravityType GmStringToGravityType
+#define StringToHighlightStyle GmStringToHighlightStyle
+#define StringToImageType GmStringToImageType
+#define StringToInterlaceType GmStringToInterlaceType
 #define StringToList GmStringToList
+#define StringToMetricType GmStringToMetricType
+#define StringToNoiseType GmStringToNoiseType
+#define StringToPreviewType GmStringToPreviewType
+#define StringToQuantumOperator GmStringToQuantumOperator
+#define StringToResourceType GmStringToResourceType
+#define StringToVirtualPixelMethod GmStringToVirtualPixelMethod
 #define Strip GmStrip
+#define StripImage GmStripImage
+#define StyleTypeToString GmStyleTypeToString
 #define SubstituteString GmSubstituteString
 #define SwirlImage GmSwirlImage
 #define SyncCacheView GmSyncCacheView
+#define SyncCacheViewPixels GmSyncCacheViewPixels
 #define SyncImage GmSyncImage
 #define SyncImagePixels GmSyncImagePixels
+#define SyncImagePixelsEx GmSyncImagePixelsEx
 #define SyncNextImageInList GmSyncNextImageInList
 #define SystemCommand GmSystemCommand
 #define TellBlob GmTellBlob
@@ -728,6 +966,7 @@
 #define ThresholdImage GmThresholdImage
 #define ThrowLoggedException GmThrowLoggedException
 #define ThumbnailImage GmThumbnailImage
+#define TimeImageCommand GmTimeImageCommand
 #define Tokenizer GmTokenizer
 #define TransformColorspace GmTransformColorspace
 #define TransformHSL GmTransformHSL
@@ -736,6 +975,7 @@
 #define TransformRGBImage GmTransformRGBImage
 #define TransformSignature GmTransformSignature
 #define TranslateText GmTranslateText
+#define TranslateTextEx GmTranslateTextEx
 #define TransparentImage GmTransparentImage
 #define UnlockSemaphoreInfo GmUnlockSemaphoreInfo
 #define UnmapBlob GmUnmapBlob
@@ -743,20 +983,18 @@
 #define UnregisterAVIImage GmUnregisterAVIImage
 #define UnregisterAVSImage GmUnregisterAVSImage
 #define UnregisterBMPImage GmUnregisterBMPImage
+#define UnregisterCALSImage GmUnregisterCALSImage
 #define UnregisterCAPTIONImage GmUnregisterCAPTIONImage
 #define UnregisterCINEONImage GmUnregisterCINEONImage
-#define UnregisterCLIPBOARDImage GmUnregisterCLIPBOARDImage
 #define UnregisterCMYKImage GmUnregisterCMYKImage
 #define UnregisterCUTImage GmUnregisterCUTImage
 #define UnregisterDCMImage GmUnregisterDCMImage
+#define UnregisterDCRAWImage GmUnregisterDCRAWImage
 #define UnregisterDIBImage GmUnregisterDIBImage
-#define UnregisterDPSImage GmUnregisterDPSImage
 #define UnregisterDPXImage GmUnregisterDPXImage
-#define UnregisterEMFImage GmUnregisterEMFImage
 #define UnregisterEPTImage GmUnregisterEPTImage
 #define UnregisterFAXImage GmUnregisterFAXImage
 #define UnregisterFITSImage GmUnregisterFITSImage
-#define UnregisterFPXImage GmUnregisterFPXImage
 #define UnregisterGIFImage GmUnregisterGIFImage
 #define UnregisterGRADIENTImage GmUnregisterGRADIENTImage
 #define UnregisterGRAYImage GmUnregisterGRAYImage
@@ -764,14 +1002,15 @@
 #define UnregisterHRZImage GmUnregisterHRZImage
 #define UnregisterHTMLImage GmUnregisterHTMLImage
 #define UnregisterICONImage GmUnregisterICONImage
-#define UnregisterJBIGImage GmUnregisterJBIGImage
+#define UnregisterIDENTITYImage GmUnregisterIDENTITYImage
+#define UnregisterINFOImage GmUnregisterINFOImage
 #define UnregisterJNXImage GmUnregisterJNXImage
 #define UnregisterJP2Image GmUnregisterJP2Image
 #define UnregisterJPEGImage GmUnregisterJPEGImage
 #define UnregisterLABELImage GmUnregisterLABELImage
 #define UnregisterLOCALEImage GmUnregisterLOCALEImage
 #define UnregisterLOGOImage GmUnregisterLOGOImage
-#define UnregisterMACImage GmUnregisterMATImage
+#define UnregisterMACImage GmUnregisterMACImage
 #define UnregisterMAPImage GmUnregisterMAPImage
 #define UnregisterMATImage GmUnregisterMATImage
 #define UnregisterMATTEImage GmUnregisterMATTEImage
@@ -813,6 +1052,7 @@
 #define UnregisterSTEGANOImage GmUnregisterSTEGANOImage
 #define UnregisterSUNImage GmUnregisterSUNImage
 #define UnregisterSVGImage GmUnregisterSVGImage
+#define UnregisterStaticModules GmUnregisterStaticModules
 #define UnregisterTGAImage GmUnregisterTGAImage
 #define UnregisterTIFFImage GmUnregisterTIFFImage
 #define UnregisterTILEImage GmUnregisterTILEImage
@@ -837,11 +1077,13 @@
 #define UnregisterXWDImage GmUnregisterXWDImage
 #define UnregisterYUVImage GmUnregisterYUVImage
 #define UnsharpMaskImage GmUnsharpMaskImage
-#define UnshiftImageList GmUnshiftImageList
+#define UnsharpMaskImageChannel GmUnsharpMaskImageChannel
 #define UpdateSignature GmUpdateSignature
 #define WaveImage GmWaveImage
+#define WhiteThresholdImage GmWhiteThresholdImage
 #define WriteBlob GmWriteBlob
 #define WriteBlobByte GmWriteBlobByte
+#define WriteBlobFile GmWriteBlobFile
 #define WriteBlobLSBLong GmWriteBlobLSBLong
 #define WriteBlobLSBShort GmWriteBlobLSBShort
 #define WriteBlobMSBLong GmWriteBlobMSBLong
@@ -851,15 +1093,8 @@
 #define WriteBlobStringWithEOL GmWriteBlobStringWithEOL
 #define WriteImage GmWriteImage
 #define WriteImages GmWriteImages
-#define WriteStream GmWriteStream
+#define WriteImagesFile GmWriteImagesFile
 #define ZoomImage GmZoomImage
-#define _MagickError Gm_MagickError
-#define _MagickFatalError Gm_MagickFatalError
-#define _MagickWarning Gm_MagickWarning
-/* #define MagickError GmMagickError */
-/* #define MagickFatalError GmMagickFatalError */
-/* #define MagickWarning GmMagickWarning */
-/* #define ThrowException GmThrowException */
 
 #endif /* defined(PREFIX_MAGICK_SYMBOLS) */
 #endif /* defined(_MAGICK_SYMBOLS_H) */
